==> 0.1.3.tar.gz: lib/model_form/model_form.dart <==
import 'package:flutter/widgets.dart';
import 'package:json_form/element_form.dart';
import 'package:json_form/element_form/layouts/i_layout.dart';

import 'adapters/i_element_adapter.dart';

class ModelForm<T> extends ElementForm {
  final T Function(dynamic hash) _fromHash;

  ModelForm(
      T model,
      List<IElementAdapter> adapters,
      dynamic Function(T model) toHash,
      T Function(dynamic hash) fromHash,
      Widget Function(BuildContext context, dynamic widgets) build,
      {Key key})
      : _fromHash = fromHash,
        super(_modelToElements<T>(model, adapters, toHash), build, key: key);

  static dynamic _modelToElements<T>(T model, List<IElementAdapter> adapters,
      dynamic Function(T model) toHash) {
    dynamic hash = toHash(model);

    TreeMapper mapper = TreeMapper((dynamic node) {
      for (IElementAdapter adapter in adapters) {
        if (adapter.isMatch(node)) {
          return adapter.adapt(node);
        }
      }

      return null;
    });

    return mapper.map(hash);
  }

  @override
  State<StatefulWidget> createState() => ModelFormState<T>();

  // Static layout factories
  static ModelForm withLayout<T>(ILayout layout, T model,
      List<IElementAdapter> adapters,
      dynamic Function(T model) toHash,
      T Function(dynamic hash) fromHash,
      {Key key}) {
    return ModelForm<T>(
      model,
      adapters,
      toHash,
      fromHash,
      layout.layout,
      key: key,
    );
  }
}

class ModelFormState<T> extends ElementFormState<dynamic, ModelForm> {
  @override
  T save() {
    return widget._fromHash(super.save());
  }
}

==> 0.1.4.tar.gz: lib/model_form/model_form.dart <==
import 'package:flutter/widgets.dart';
import 'package:json_form/element_form.dart';
import 'package:json_form/element_form/layouts/i_layout.dart';

import 'adapters/i_element_adapter.dart';

class ModelForm<T> extends ElementForm {
  final T Function(dynamic hash) _fromHash;

  ModelForm(
      T model,
      List<IElementAdapter> adapters,
      dynamic Function(T model) toHash,
      T Function(dynamic hash) fromHash,
      Widget Function(BuildContext context, dynamic widgets) build,
      {Key key})
      : _fromHash = fromHash,
        super(_modelToElements<T>(model, adapters, toHash), build, key: key);

  static dynamic _modelToElements<T>(T model, List<IElementAdapter> adapters,
      dynamic Function(T model) toHash) {
    dynamic hash = toHash(model);

    TreeMapper mapper = TreeMapper((dynamic node) {
      // If node already is a form element there is no need for adapting
      if (node is FormElement) {
        return node;
      }

      // Look for matching adapter
      for (IElementAdapter adapter in adapters) {
        if (adapter.isMatch(node)) {
          return adapter.adapt(node);
        }
      }

      // Unable to map
      return null;
    });

    return mapper.map(hash);
  }

  @override
  State<StatefulWidget> createState() => ModelFormState<T>();

  // Static layout factories
  static ModelForm withLayout<T>(
      ILayout layout,
      T model,
      List<IElementAdapter> adapters,
      dynamic Function(T model) toHash,
      T Function(dynamic hash) fromHash,
      {Key key}) {
    return ModelForm<T>(
      model,
      adapters,
      toHash,
      fromHash,
      layout.layout,
      key: key,
    );
  }
}

class ModelFormState<T> extends ElementFormState<dynamic, ModelForm> {
  @override
  T save() {
    return widget._fromHash(super.save());
  }
}
